==> apache-camel-4.10.9-src.zip: apache-camel-4.10.9/core/camel-management/src/main/java/org/apache/camel/management/mbean/ManagedSetExchangePattern.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.management.mbean;

import org.apache.camel.CamelContext;
import org.apache.camel.api.management.ManagedResource;
import org.apache.camel.api.management.mbean.ManagedSetExchangePatternMBean;
import org.apache.camel.model.ProcessorDefinition;
import org.apache.camel.processor.ExchangePatternProcessor;

@ManagedResource(description = "Managed SetExchangePattern")
public class ManagedSetExchangePattern extends ManagedProcessor implements ManagedSetExchangePatternMBean {
    private final ExchangePatternProcessor processor;

    public ManagedSetExchangePattern(CamelContext context, ExchangePatternProcessor processor,
                                     ProcessorDefinition<?> definition) {
        super(context, processor, definition);
        this.processor = processor;
    }

    @Override
    public String getPattern() {
        return processor.getExchangePattern().name();
    }
}

==> apache-camel-4.14.4-src.zip: apache-camel-4.14.4/core/camel-management/src/main/java/org/apache/camel/management/mbean/ManagedSetExchangePattern.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.management.mbean;

import org.apache.camel.CamelContext;
import org.apache.camel.api.management.ManagedResource;
import org.apache.camel.api.management.mbean.ManagedSetExchangePatternMBean;
import org.apache.camel.model.ProcessorDefinition;
import org.apache.camel.processor.ExchangePatternProcessor;

@ManagedResource(description = "Managed SetExchangePattern")
public class ManagedSetExchangePattern extends ManagedProcessor implements ManagedSetExchangePatternMBean {

    public ManagedSetExchangePattern(CamelContext context, ExchangePatternProcessor processor,
                                     ProcessorDefinition<?> definition) {
        super(context, processor, definition);
    }

    @Override
    public ExchangePatternProcessor getProcessor() {
        return (ExchangePatternProcessor) super.getProcessor();
    }

    @Override
    public String getPattern() {
        return getProcessor().getExchangePattern().name();
    }
}
